Title: [280834] releases/WebKitGTK/webkit-2.32/Source/WebCore
Revision
280834
Author
[email protected]
Date
2021-08-10 02:27:27 -0700 (Tue, 10 Aug 2021)

Log Message

Merge r274144 - [Multi-column] Adjust fragmented flow state of the out-of-flow descendants
https://bugs.webkit.org/show_bug.cgi?id=222958
<rdar://74865741>

Reviewed by Antti Koivisto.

When a block container's style change from positioned to non-positioned and it is part of a multi-column context,
we need to make sure that the out-of-flow positined descendants' flow state are updated accordingly (as
they may not be part of the multi-column context anymore).

* rendering/RenderElement.cpp:
(WebCore::RenderElement::adjustFragmentedFlowStateOnContainingBlockChangeIfNeeded):

Modified Paths

Diff

Modified: releases/WebKitGTK/webkit-2.32/Source/WebCore/ChangeLog (280833 => 280834)


--- releases/WebKitGTK/webkit-2.32/Source/WebCore/ChangeLog	2021-08-10 09:27:19 UTC (rev 280833)
+++ releases/WebKitGTK/webkit-2.32/Source/WebCore/ChangeLog	2021-08-10 09:27:27 UTC (rev 280834)
@@ -1,3 +1,18 @@
+2021-03-09  Zalan Bujtas  <[email protected]>
+
+        [Multi-column] Adjust fragmented flow state of the out-of-flow descendants
+        https://bugs.webkit.org/show_bug.cgi?id=222958
+        <rdar://74865741>
+
+        Reviewed by Antti Koivisto.
+
+        When a block container's style change from positioned to non-positioned and it is part of a multi-column context,
+        we need to make sure that the out-of-flow positined descendants' flow state are updated accordingly (as
+        they may not be part of the multi-column context anymore).
+
+        * rendering/RenderElement.cpp:
+        (WebCore::RenderElement::adjustFragmentedFlowStateOnContainingBlockChangeIfNeeded):
+
 2021-03-08  Julian Gonzalez  <[email protected]>
 
         Crash in in ReplaceSelectionCommand::mergeEndIfNeeded()

Modified: releases/WebKitGTK/webkit-2.32/Source/WebCore/rendering/RenderElement.cpp (280833 => 280834)


--- releases/WebKitGTK/webkit-2.32/Source/WebCore/rendering/RenderElement.cpp	2021-08-10 09:27:19 UTC (rev 280833)
+++ releases/WebKitGTK/webkit-2.32/Source/WebCore/rendering/RenderElement.cpp	2021-08-10 09:27:27 UTC (rev 280834)
@@ -2177,8 +2177,8 @@
     if (is<RenderBlock>(*this))
         downcast<RenderBlock>(*this).resetEnclosingFragmentedFlowAndChildInfoIncludingDescendants();
     else {
-        // Relatively positioned inline boxes can have absolutely positioned block children. We need to reset them as well.
-        for (auto& descendant : childrenOfType<RenderBlock>(*this))
+        // Relatively positioned inline boxes can have absolutely positioned block descendants. We need to reset them as well.
+        for (auto& descendant : descendantsOfType<RenderBlock>(*this))
             descendant.resetEnclosingFragmentedFlowAndChildInfoIncludingDescendants();
     }
     
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to